Revision: 2193
http://nagiosplug.svn.sourceforge.net/nagiosplug/?rev=2193&view=rev
Author: dermoth
Date: 2009-05-19 22:16:36 +0000 (Tue, 19 May 2009)
Log Message:
-----------
Fix a few minor typos
Signed-off-by: Holger Weiss <[email protected]>
Modified Paths:
--------------
nagiosplug/trunk/plugins/check_ups.c
nagiosplug/trunk/plugins/urlize.c
Modified: nagiosplug/trunk/plugins/check_ups.c
===================================================================
--- nagiosplug/trunk/plugins/check_ups.c 2009-05-19 22:16:26 UTC (rev 2192)
+++ nagiosplug/trunk/plugins/check_ups.c 2009-05-19 22:16:36 UTC (rev 2193)
@@ -12,8 +12,8 @@
*
* This file contains Network UPS Tools plugin for Nagios
*
-* This plugin tests the UPS service on the specified host.Network UPS Tools
-* from www.networkupstools.org must be running for thisplugin to work.
+* This plugin tests the UPS service on the specified host. Network UPS Tools
+* from www.networkupstools.org must be running for this plugin to work.
*
*
* This program is free software: you can redistribute it and/or modify
@@ -605,7 +605,7 @@
printf (COPYRIGHT, copyright, email);
printf ("%s\n", _("This plugin tests the UPS service on the specified host. Network UPS Tools"));
- printf ("%s\n", _("from www.networkupstools.org must be running for thisplugin to work."));
+ printf ("%s\n", _("from www.networkupstools.org must be running for this plugin to work."));
printf ("\n\n");
@@ -641,12 +641,12 @@
printf ("\n");
printf ("%s\n", _("Notes:"));
printf (" %s\n", _("You may also specify a variable to check (such as temperature, utility voltage,"));
- printf (" %s\n", _("battery load, etc.) as well as warning and critical thresholds for the value"));
+ printf (" %s\n", _("battery load, etc.) as well as warning and critical thresholds for the value"));
printf (" %s\n", _("of that variable. If the remote host has multiple UPS that are being monitored"));
printf (" %s\n", _("you will have to use the --ups option to specify which UPS to check."));
printf ("\n");
printf (" %s\n", _("This plugin requires that the UPSD daemon distributed with Russell Kroll's"));
- printf (" %s\n", _("Smart UPS Tools be installed on the remote host. If you do not have the"));
+ printf (" %s\n", _("Network UPS Tools be installed on the remote host. If you do not have the"));
printf (" %s\n", _("package installed on your system, you can download it from"));
printf (" %s\n", _("http://www.networkupstools.org"));
#ifdef NP_EXTRA_OPTS
Modified: nagiosplug/trunk/plugins/urlize.c
===================================================================
--- nagiosplug/trunk/plugins/urlize.c 2009-05-19 22:16:26 UTC (rev 2192)
+++ nagiosplug/trunk/plugins/urlize.c 2009-05-19 22:16:36 UTC (rev 2193)
@@ -10,8 +10,8 @@
* This file contains the urlize plugin
*
* This plugin wraps the text output of another command (plugin) in HTML <A>
* tags, thus displaying the plugin output in as a clickable link in the
* Nagios status screen. The return status is the same as the invoked plugin.
*
*
* This program is free software: you can redistribute it and/or modify
@@ -167,8 +167,8 @@
printf (COPYRIGHT, copyright, email);
printf ("%s\n", _("This plugin wraps the text output of another command (plugin)"));
- printf ("%s\n", _("in HTML <A> tags, thus displaying the plugin output in as a clickable link in"));
- printf ("%s\n", _("the Nagios status screen. The return status is the same as the invoked plugin."));
+ printf ("%s\n", _("in HTML <A> tags, thus displaying the child plugin's output as a clickable link in"));
+ printf ("%s\n", _("the Nagios status screen. This plugin returns the status of the invoked plugin."));
printf ("\n\n");
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
------------------------------------------------------------------------------
Crystal Reports - New Free Runtime and 30 Day Trial
Check out the new simplified licensing option that enables
unlimited royalty-free distribution of the report engine
@@ -10,8 +10,8 @@
*
* This plugin wraps the text output of another command (plugin) in HTML <A>
-* tags, thus displaying the plugin output in as a clickable link in the
-* Nagios status screen. The return status is the same as the invoked plugin.
+* tags, thus displaying the child plugin's output as a clickable link in the
+* Nagios status screen. This plugin returns the status of the invoked plugin.
*
*
for externally facing server and web deployment.
http://p.sf.net/sfu/businessobjects
lmpx.com only provides a reader for public news (NNTP) servers. It is not
affiliated with the servers or forums shown here and is not responsible for
the content of articles, which is written by their respective authors.